@@ -49,6 +49,10 @@ type AzureOptions struct {
 	// flow exchange. Ensure that your OIDC application is configured to accept
 	// these URIs otherwise an error may occur.
 	RedirectURIs []string
+	// RemoteRedirectURI is an optional redirect URI to use. If set, this overrides the
+	// RedirectURIs value sent to the OP during authorization. We still open a
+	// localhost URI expecting the remote server to proxy the request to a localhost port.
+	RemoteRedirectURI string
 	// GQSign denotes if the received ID token should be upgraded to a GQ token
 	// using GQ signatures.
 	GQSign bool
@@ -119,6 +123,7 @@ func NewAzureOpWithOptions(opts *AzureOptions) BrowserOpenIdProvider {
 			HttpClient:                opts.HttpClient,
 			IssuedAtOffset:            opts.IssuedAtOffset,
 			issuer:                    opts.Issuer,
+			RemoteRedirectURI:         opts.RemoteRedirectURI,
 			requestTokensOverrideFunc: nil,
 			publicKeyFinder: discover.PublicKeyFinder{
 				JwksFunc: func(ctx context.Context, issuer string) ([]byte, error) {
