@@ -48,6 +48,10 @@ type GitlabOptions struct {
 	// flow exchange. Ensure that your OIDC application is configured to accept
 	// these URIs otherwise an error may occur.
 	RedirectURIs []string
+	// RemoteRedirectURI is an optional redirect URI to use. If set, this overrides the
+	// RedirectURIs value sent to the OP during authorization. We still open a
+	// localhost URI expecting the remote server to proxy the request to a localhost port.
+	RemoteRedirectURI string
 	// GQSign denotes if the received ID token should be upgraded to a GQ token
 	// using GQ signatures.
 	GQSign bool
@@ -102,6 +106,7 @@ func NewGitlabOpWithOptions(opts *GitlabOptions) BrowserOpenIdProvider {
 			PromptType:                opts.PromptType,
 			AccessType:                opts.AccessType,
 			RedirectURIs:              opts.RedirectURIs,
+			RemoteRedirectURI:         opts.RemoteRedirectURI,
 			GQSign:                    opts.GQSign,
 			OpenBrowser:               opts.OpenBrowser,
 			HttpClient:                opts.HttpClient,
